==> kubernetes-model-apiextensions-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1/ExternalDocumentationFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ExternalDocumentationFluent<A extends ExternalDocumentationFluent<A>> extends Fluent<A> {


    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public A withNewDescription(StringBuilder arg1);
    public A withNewDescription(int[] arg1,int arg2,int arg3);
    public A withNewDescription(char[] arg1);
    public A withNewDescription(StringBuffer arg1);
    public A withNewDescription(byte[] arg1,int arg2);
    public A withNewDescription(byte[] arg1);
    public A withNewDescription(char[] arg1,int arg2,int arg3);
    public A withNewDescription(byte[] arg1,int arg2,int arg3);
    public A withNewDescription(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDescription(String arg1);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(int[] arg1,int arg2,int arg3);
    public A withNewUrl(char[] arg1);
    public A withNewUrl(StringBuffer arg1);
    public A withNewUrl(byte[] arg1,int arg2);
    public A withNewUrl(byte[] arg1);
    public A withNewUrl(char[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUrl(String arg1);
}

==> kubernetes-model-apiextensions-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1/ExternalDocumentationFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ExternalDocumentationFluent<A extends ExternalDocumentationFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public A withNewDescription(StringBuilder arg1);
    public A withNewDescription(int[] arg1,int arg2,int arg3);
    public A withNewDescription(char[] arg1);
    public A withNewDescription(StringBuffer arg1);
    public A withNewDescription(byte[] arg1,int arg2);
    public A withNewDescription(byte[] arg1);
    public A withNewDescription(char[] arg1,int arg2,int arg3);
    public A withNewDescription(byte[] arg1,int arg2,int arg3);
    public A withNewDescription(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDescription(String arg1);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(int[] arg1,int arg2,int arg3);
    public A withNewUrl(char[] arg1);
    public A withNewUrl(StringBuffer arg1);
    public A withNewUrl(byte[] arg1,int arg2);
    public A withNewUrl(byte[] arg1);
    public A withNewUrl(char[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUrl(String arg1);
}
